@@ -308,6 +308,18 @@ def test_os_build_compare():
     assert not res
     res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1-1ubuntu2.1")
     assert not res
+    res = utils.version_compare("0.23.22-1.amzn2.0.1", 0, "*", None, "0.23.22")
+    assert not res
+
+
+def test_ubuntu_openssl():
+    res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1.e")
+    assert not res
+
+
+def test_debian_build_compare():
+    res = utils.version_compare("1:2019.10.06-1", 0, "*", None, "20070829-6+deb7u1")
+    assert not res
 
 
 def test_parse_uri():
