@@ -10,6 +10,7 @@ from tabulate import tabulate
 
 from vdb.lib import config as config
 from vdb.lib import db as dbLib
+from vdb.lib.aqua import AquaSource
 from vdb.lib.gha import GitHubSource
 from vdb.lib.npm import NpmSource
 from vdb.lib.nvd import NvdSource
@@ -53,6 +54,13 @@ def build_args():
         dest="cache",
         help="Cache vulnerability information in platform specific user_data_dir",
     )
+    parser.add_argument(
+        "--cache-os",
+        action="store_true",
+        default=False,
+        dest="cache_os",
+        help="Cache OS vulnerability information in platform specific user_data_dir",
+    )
     parser.add_argument(
         "--only-osv",
         action="store_true",
@@ -60,6 +68,13 @@ def build_args():
         dest="only_osv",
         help="Use only OSV as the source. Use with --cache.",
     )
+    parser.add_argument(
+        "--only-aqua",
+        action="store_true",
+        default=False,
+        dest="only_aqua",
+        help="Use only Aqua vuln-list as the source. Use with --cache.",
+    )
     parser.add_argument(
         "--sync",
         action="store_true",
@@ -154,11 +169,15 @@ def main():
                 os.rmdir(config.data_dir)
             except Exception:
                 pass
-    if args.cache:
+    if args.cache or args.cache_os:
         if args.only_osv:
             sources = [OSVSource()]
+        elif args.only_aqua:
+            sources = [AquaSource()]
         else:
             sources = [OSVSource(), GitHubSource(), NvdSource()]
+        if args.cache_os:
+            sources.insert(0, AquaSource())
         for s in sources:
             LOG.info("Refreshing {}".format(s.__class__.__name__))
             s.refresh()
