@@ -330,7 +330,8 @@ class AquaSource(NvdSource):
         lastModifiedDate = cve_data.get("PublicDate")
         for pkg_name, distro_obj in packages.items():
             for distro_name, status_obj in distro_obj.items():
-                if not status_obj.get("Note"):
+                # Skip devel branch and those without version numbers
+                if not status_obj.get("Note") or distro_name in ("devel"):
                     continue
                 version_start_including = ""
                 version_end_including = ""
@@ -341,6 +342,9 @@ class AquaSource(NvdSource):
                 fix_version_end_excluding = ""
                 fix_version_start_including = ""
                 fix_note = status_obj.get("Note")
+                # Remove epoch
+                if ":" in fix_note:
+                    fix_note = fix_note.split(":")[-1]
                 if (
                     status_obj.get("Status")
                     in (
