@@ -297,11 +297,16 @@ def convert_to_semver(version):
             ver["prerelease"] = int(prefloat)
         except Exception:
             pre_str = ver.get("prerelease", "").lower()
-            for s in KNOWN_PRERELEASE_STR:
-                if s in pre_str:
-                    ver["prerelease"] = 0
-                    ver["build"] = 0
-                    break
+            # If the prerelease is a single alphabet then ignore it
+            if len(pre_str) == 1:
+                ver["prerelease"] = 0
+                ver["build"] = ord(pre_str)
+            else:
+                for s in KNOWN_PRERELEASE_STR:
+                    if s in pre_str:
+                        ver["prerelease"] = 0
+                        ver["build"] = 0
+                        break
 
     ver = VersionInfo(**ver)
     rest = match.string[match.end() :]  # noqa:E203
@@ -339,7 +344,14 @@ def checkEpoch(s):
     m = DEBIAN_VALID_VERSION.search(s)
     if m and m.group("epoch"):
         return True
-    if ":" in s or "ubuntu" in s or "deb" in s or "mint" in s:
+    if (
+        ":" in s
+        or "ubuntu" in s
+        or "deb" in s
+        or "mint" in s
+        or "amzn" in s
+        or "oracle" in s
+    ):
         return True
     return False
 
@@ -489,7 +501,18 @@ def version_compare(
             min_check = min_value > 0 if is_min_exclude else min_value >= 0
             max_check = max_value < 0 if is_max_exclude else max_value <= 0
             return min_check and max_check
-
+        # Are we dealing with dates?
+        if compare_ver.startswith("20") and (
+            min_version.startswith("20") or max_version.startswith("20")
+        ):
+            # Compare_ver has dots where as min and max do not.
+            # So we convert all of them to dates
+            if (
+                "." not in min_version or "." not in max_version
+            ) and "." in compare_ver:
+                compare_ver = compare_ver.replace(".", "")
+                min_version = min_version.replace(".", "")
+                max_version = max_version.replace(".", "")
         # We have an incompatible semver string. Try to convert to semver format
         compare_semver, comprest = convert_to_semver(compare_ver)
         min_semver, minrest = convert_to_semver(
